@@ -4,6 +4,7 @@
 
 import logging
 import os.path
+
 from fusesoc.provider.provider import Provider
 
 logger = logging.getLogger(__name__)
@@ -13,9 +14,7 @@ class Local(Provider):
     @staticmethod
     def init_library(library):
         if not os.path.isdir(library.location):
-            logger.error(
-                "Local library at location '{}' not found.".format(library.location)
-            )
+            logger.error(f"Local library at location '{library.location}' not found.")
             exit(1)
 
     def _checkout(self, local_dir):
